==> r-cran-ggsci_2.9.orig.tar.gz: ggsci/R/discrete-jco.R <==
#' Journal of Clinical Oncology Color Palettes
#'
#' Color palette inspired by plots in \emph{Journal of Clinical Oncology}.
#'
#' @param palette Palette type.
#' Currently there is one available option: \code{"default"}
#' (10-color palette).
#' @param alpha Transparency level, a real number in (0, 1].
#' See \code{alpha} in \code{\link[grDevices]{rgb}} for details.
#'
#' @export pal_jco
#'
#' @importFrom grDevices col2rgb rgb
#' @importFrom scales manual_pal
#'
#' @author Nan Xiao <\email{me@@nanx.me}> |
#' <\href{https://nanx.me}{https://nanx.me}>
#'
#' @examples
#' library("scales")
#' show_col(pal_jco("default")(10))
#' show_col(pal_jco("default", alpha = 0.6)(10))
pal_jco = function (palette = c('default'), alpha = 1) {

  palette = match.arg(palette)

  if (alpha > 1L | alpha <= 0L) stop('alpha must be in (0, 1]')

  raw_cols = ggsci_db$'jco'[[palette]]
  raw_cols_rgb = col2rgb(raw_cols)
  alpha_cols = rgb(
    raw_cols_rgb[1L, ], raw_cols_rgb[2L, ], raw_cols_rgb[3L, ],
    alpha = alpha * 255L, names = names(raw_cols),
    maxColorValue = 255L)

  manual_pal(unname(alpha_cols))

}

#' Journal of Clinical Oncology Color Scales
#'
#' See \code{\link{pal_jco}} for details.
#'
#' @inheritParams pal_jco
#' @param ... additional parameters for \code{\link[ggplot2]{discrete_scale}}
#'
#' @export scale_color_jco
#'
#' @importFrom ggplot2 discrete_scale
#'
#' @author Nan Xiao <\email{me@@nanx.me}> |
#' <\href{https://nanx.me}{https://nanx.me}>
#'
#' @rdname scale_jco
#'
#' @examples
#' library("ggplot2")
#' data("diamonds")
#'
#' ggplot(subset(diamonds, carat >= 2.2),
#'        aes(x = table, y = price, colour = cut)) +
#'   geom_point(alpha = 0.7) +
#'   geom_smooth(method = "loess", alpha = 0.1, size = 1, span = 1) +
#'   theme_bw() + scale_color_jco()
#'
#' ggplot(subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
#'        aes(x = depth, fill = cut)) +
#'   geom_histogram(colour = "black", binwidth = 1, position = "dodge") +
#'   theme_bw() + scale_fill_jco()
scale_color_jco = function (palette = c('default'), alpha = 1, ...) {

  palette = match.arg(palette)
  discrete_scale('colour', 'jco', pal_jco(palette, alpha), ...)

}

#' @export scale_colour_jco
#' @rdname scale_jco
scale_colour_jco = scale_color_jco

#' @export scale_fill_jco
#' @importFrom ggplot2 discrete_scale
#' @rdname scale_jco
scale_fill_jco = function (palette = c('default'), alpha = 1, ...) {

  palette = match.arg(palette)
  discrete_scale('fill', 'jco', pal_jco(palette, alpha), ...)

}

==> r-cran-ggsci_3.0.0.orig.tar.gz: ggsci/R/discrete-jco.R <==
#' Journal of Clinical Oncology Color Palettes
#'
#' Color palette inspired by plots in \emph{Journal of Clinical Oncology}.
#'
#' @param palette Palette type.
#' Currently there is one available option: \code{"default"}
#' (10-color palette).
#' @param alpha Transparency level, a real number in (0, 1].
#' See \code{alpha} in \code{\link[grDevices]{rgb}} for details.
#'
#' @export pal_jco
#'
#' @importFrom grDevices col2rgb rgb
#' @importFrom scales manual_pal
#'
#' @author Nan Xiao <\email{me@@nanx.me}> |
#' <\href{https://nanx.me}{https://nanx.me}>
#'
#' @examples
#' library("scales")
#' show_col(pal_jco("default")(10))
#' show_col(pal_jco("default", alpha = 0.6)(10))
pal_jco <- function(palette = c("default"), alpha = 1) {
  palette <- match.arg(palette)

  if (alpha > 1L | alpha <= 0L) stop("alpha must be in (0, 1]")

  raw_cols <- ggsci_db$"jco"[[palette]]
  raw_cols_rgb <- col2rgb(raw_cols)
  alpha_cols <- rgb(
    raw_cols_rgb[1L, ], raw_cols_rgb[2L, ], raw_cols_rgb[3L, ],
    alpha = alpha * 255L, names = names(raw_cols),
    maxColorValue = 255L
  )

  manual_pal(unname(alpha_cols))
}

#' Journal of Clinical Oncology Color Scales
#'
#' See \code{\link{pal_jco}} for details.
#'
#' @inheritParams pal_jco
#' @param ... additional parameters for \code{\link[ggplot2]{discrete_scale}}
#'
#' @export scale_color_jco
#'
#' @importFrom ggplot2 discrete_scale
#'
#' @author Nan Xiao <\email{me@@nanx.me}> |
#' <\href{https://nanx.me}{https://nanx.me}>
#'
#' @rdname scale_jco
#'
#' @examples
#' library("ggplot2")
#' data("diamonds")
#' 
#' ggplot(
#'   subset(diamonds, carat >= 2.2),
#'   aes(x = table, y = price, colour = cut)
#' ) +
#'   geom_point(alpha = 0.7) +
#'   geom_smooth(method = "loess", alpha = 0.1, size = 1, span = 1) +
#'   theme_bw() + scale_color_jco()
#' 
#' ggplot(
#'   subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
#'   aes(x = depth, fill = cut)
#' ) +
#'   geom_histogram(colour = "black", binwidth = 1, position = "dodge") +
#'   theme_bw() + scale_fill_jco()
scale_color_jco <- function(palette = c("default"), alpha = 1, ...) {
  palette <- match.arg(palette)
  discrete_scale("colour", "jco", pal_jco(palette, alpha), ...)
}

#' @export scale_colour_jco
#' @rdname scale_jco
scale_colour_jco <- scale_color_jco

#' @export scale_fill_jco
#' @importFrom ggplot2 discrete_scale
#' @rdname scale_jco
scale_fill_jco <- function(palette = c("default"), alpha = 1, ...) {
  palette <- match.arg(palette)
  discrete_scale("fill", "jco", pal_jco(palette, alpha), ...)
}
